import {Component, OnInit} from '@angular/core';
import {ADMIN_INFO_OBJECT} from '../../../services/local-storage.namespace';
import {LocalStorageService} from '../../../services/local-storage.service';
import {CommonsService} from '../../../services/commons.service';
import {IndexService} from '../../../services/index.service';
import {NzMessageService} from '_ng-zorro-antd@9.3.0@ng-zorro-antd';
import {environment} from '../../../../environments/environment';


@Component({
  selector: 'app-index',
  templateUrl: './index.component.html',
  styleUrls: ['./index.component.less']
})
export class IndexComponent implements OnInit {
  FILE_URL = environment.imageUrl;
  roleType: number;
  loading = true;
  isVisible = false;
  isVisibleAdd = false;
  balance: number;
  price: number;
  code = 60;
  listOfData;
  countData: any = {};
  data: any = {};
  orderData = {};
  balanceData = {};
  rechargeData = {};
  constructor(
      private store: LocalStorageService, // 数据缓存
      private message: NzMessageService, // 信息提示
      private index: IndexService
  ) { }

  ngOnInit(): void {
    this.roleType = this.store.get(ADMIN_INFO_OBJECT)['secRole'].roleType;
    if (this.roleType === 1) {
      this.getIndexCount();
      this.getLineCount();
    }

    if (this.store.get(ADMIN_INFO_OBJECT)['highAgent'] != null) {
      this.code = this.store.get(ADMIN_INFO_OBJECT)['highAgent'].id;
    }
    if (this.store.get(ADMIN_INFO_OBJECT)['bsCompany'].id === 3) {
      this.code = 60;
      this.getHLTBalance();
      this.orderByIndex();
      this.HLTOrderByIndex();
      this.rechargeOrderByIndex();
      this.HLTOrderByList();
    }

  }

  // 查询余额
  public getHLTBalance(): void {
    const paramsObject = {
      codeType: 'HLT_BALANCE'
    };
    this.index.getHLTBalance(paramsObject , data => {
      if (data['return_code'] === '000000') {
        this.loading = false;
        this.balance = data['return_data'];
      } else {
        this.message.error(data['return_msg']);
      }
    });
  }

  public orderByIndex(): void {
     this.index.orderByIndex(this.code , data => {
       if (data['return_code'] === '000000') {
         this.orderData = data['return_data'];
         this.loading = false;
       } else {
         this.message.error(data['return_msg']);
       }
     });
  }

  public HLTOrderByIndex(): void {
    this.index.HLTOrderByIndex(this.code , data => {
      if (data['return_code'] === '000000') {
        this.balanceData = data['return_data'];
        this.loading = false;
      } else {
        this.message.error(data['return_msg']);
      }
    });
  }

  public rechargeOrderByIndex(): void {
    this.index.rechargeOrderByIndex(this.code , data => {
      if (data['return_code'] === '000000') {
        this.rechargeData = data['return_data'];
        this.loading = false;
      } else {
        this.message.error(data['return_msg']);
      }
    });
  }

  public HLTOrderByList(): void {
    this.index.HLTOrderByList(this.code , data => {
      if (data['return_code'] === '000000') {
        this.listOfData = data['return_data'];
      } else {
        this.message.error(data['return_msg']);
      }
    });
  }

  public getIndexCount(): void {
    this.index.getIndexCount(data => {
      if (data['return_code'] === '000000') {
        this.loading = false;
        this.countData = data['return_data'];
      } else {
        this.message.error(data['return_msg']);
      }
    });
  }

  public getLineCount(): void {
    this.index.getLineCount(data => {
      console.log(data);
      if (data['return_code'] === '000000') {
        this.data = {
          tooltip: {
            trigger: 'axis',
            axisPointer: {
              type: 'cross',
              label: {
                backgroundColor: '#6a7985'
              }
            }
          },
          legend: {},
          xAxis: {
            type: 'category',
            data: data['return_data']['date']
          },
          yAxis: {
            type: 'value'
          },
          series: [
            {
              name: '订单金额',
              data: data['return_data']['orderPriceSum'],
              type: 'line'
            },
            {
              name: '话费订单金额',
              data: data['return_data']['orderRechargePriceSum'],
              type: 'line'
            },
            {
              name: '订单数量',
              data: data['return_data']['orderCount'],
              type: 'line'
            },
            {
              name: '话费订单数量',
              data: data['return_data']['orderRechargeCount'],
              type: 'line'
            },
            {
              name: '用户注册数量',
              data: data['return_data']['userCount'],
              type: 'line'
            },
            {
              name: '话费订单金额',
              data: data['return_data']['orderRechargePriceSum'],
              type: 'line'
            }
          ]
        };
      } else {
        this.message.error(data['return_msg']);
      }
    });
  }

  // 下载模板
  downloadTemplate() {
    this.index.exportHLTOrderByList(this.code , data => {
      if (data['return_code'] === '000000') {
        window.location.href = this.FILE_URL + data['return_data'];
      } else {
        this.message.error(data['return_msg']);
      }
    });
  }


  handleOk(): void {
    if (this.price == null) {
      this.message.error('请输入充值金额');
      return;
    }
    const paramsObject = {
      codeType: 'HLT_BALANCE',
      price: this.price
    };
    this.index.addHLTBalance(paramsObject , data => {
      if (data['return_code'] === '000000') {
        this.getHLTBalance();
        this.isVisibleAdd = false;
      } else {
        this.message.error(data['return_msg']);
      }
    });
  }

}
